net: cosmetic: Fix checkpatch.pl failures in net.c

Finish eliminating CamelCase from net.c and other failures

Signed-off-by: Joe Hershberger <joe.hershberger@ni.com>
Acked-by: Simon Glass <sjg@chromium.org>
diff --git a/drivers/net/netconsole.c b/drivers/net/netconsole.c
index c2e0184..31042a6 100644
--- a/drivers/net/netconsole.c
+++ b/drivers/net/netconsole.c
@@ -113,7 +113,7 @@
 }
 
 /**
  * Called from NetLoop in net/net.c before each packet
  */
 void nc_start(void)
 {
@@ -121,7 +121,7 @@
 	if (!output_packet_len || memcmp(nc_ether, net_null_ethaddr, 6)) {
 		/* going to check for input packet */
 		net_set_udp_handler(nc_handler);
-		NetSetTimeout(net_timeout, nc_timeout_handler);
+		net_set_timeout_handler(net_timeout, nc_timeout_handler);
 	} else {
 		/* send arp request */
 		uchar *pkt;
@@ -188,7 +188,7 @@
 		output_packet = buf;
 		output_packet_len = len;
 		input_recursion = 1;
-		NetLoop(NETCONS); /* wait for arp reply and send packet */
+		net_loop(NETCONS); /* wait for arp reply and send packet */
 		input_recursion = 0;
 		output_packet_len = 0;
 		return;
@@ -232,7 +232,7 @@
 
 	/*
 	 * Initialize the static IP settings and buffer pointers
 	 * incase we call net_send_udp_packet before NetLoop
 	 */
 	net_init();
 
@@ -277,7 +277,7 @@
 
 	net_timeout = 0;	/* no timeout */
 	while (!input_size)
-		NetLoop(NETCONS);
+		net_loop(NETCONS);
 
 	input_recursion = 0;
 
@@ -307,7 +307,7 @@
 	input_recursion = 1;
 
 	net_timeout = 1;
-	NetLoop(NETCONS);	/* kind of poll */
+	net_loop(NETCONS);	/* kind of poll */
 
 	input_recursion = 0;
@@ -113,7 +113,7 @@
 
 /**
- * Called from NetLoop in net/net.c before each packet
+ * Called from net_loop in net/net.c before each packet
  */
 void nc_start(void)
@@ -232,7 +232,7 @@
 	/*
 	 * Initialize the static IP settings and buffer pointers
-	 * incase we call net_send_udp_packet before NetLoop
+	 * incase we call net_send_udp_packet before net_loop
 	 */
 	net_init();